@@ -9,20 +9,28 @@
 
 binplot.3d<-function(x,y,z,alpha=1,topcol="#ff0000",sidecol="#aaaaaa")
 {
-x1<-c(rep(c(x[1],x[2],x[2],x[1]),3),rep(x[1],4),rep(x[2],4))
-z1<-c(rep(0,4),rep(c(0,0,z,z),4))
-y1<-c(y[1],y[1],y[2],y[2],rep(y[1],4),rep(y[2],4),rep(c(y[1],y[2],y[2],y[1]),2))
-x2<-c(rep(c(x[1],x[1],x[2],x[2]),2),rep(c(x[1],x[2],rep(x[1],3),rep(x[2],3)),2))
-z2<-c(rep(c(0,z),4),rep(0,8),rep(z,8) )
-y2<-c(rep(y[1],4),rep(y[2],4),rep(c(rep(y[1],3),rep(y[2],3),y[1],y[2]),2) )
-    rgl.quads(x1,z1,y1,col=rep(sidecol,each=4),alpha=alpha)
-    rgl.quads(c(x[1],x[2],x[2],x[1]),rep(z,4),c(y[1],y[1],y[2],y[2]),
-              col=rep(topcol,each=4),alpha=1)
-    rgl.lines(x2,z2,y2,col="#000000")
+  save <- par3d(skipRedraw=TRUE)
+  on.exit(par3d(save))
+    
+  x1<-c(rep(c(x[1],x[2],x[2],x[1]),3),rep(x[1],4),rep(x[2],4))
+  z1<-c(rep(0,4),rep(c(0,0,z,z),4))
+  y1<-c(y[1],y[1],y[2],y[2],rep(y[1],4),rep(y[2],4),rep(c(y[1],y[2],y[2],y[1]),2))
+  x2<-c(rep(c(x[1],x[1],x[2],x[2]),2),rep(c(x[1],x[2],rep(x[1],3),rep(x[2],3)),2))
+  z2<-c(rep(c(0,z),4),rep(0,8),rep(z,8) )
+  y2<-c(rep(y[1],4),rep(y[2],4),rep(c(rep(y[1],3),rep(y[2],3),y[1],y[2]),2) )
+  rgl.quads(x1,z1,y1,col=rep(sidecol,each=4),alpha=alpha)
+  rgl.quads(c(x[1],x[2],x[2],x[1]),rep(z,4),c(y[1],y[1],y[2],y[2]),
+              col=rep(topcol,each=4),alpha=1) 
+  rgl.lines(x2,z2,y2,col="#000000")
 }
 
-hist3d<-function(x,y,nclass="auto",alpha=1,col="#ff0000",scale=10)
+hist3d<-function(x,y=NULL,nclass="auto",alpha=1,col="#ff0000",scale=10)
   {
+  save <- par3d(skipRedraw=TRUE)
+  on.exit(par3d(save))
+  xy <- xy.coords(x,y)
+  x <- xy$x
+  y <- xy$y
   n<-length(x)
   if (nclass == "auto") { nclass<-ceiling(sqrt(nclass.Sturges(x))) }
   breaks.x <- seq(min(x),max(x),length=(nclass+1))
@@ -35,16 +43,14 @@ hist3d<-function(x,y,nclass="auto",alpha=1,col="#ff0000",scale=10)
       z[i, j] <- (1/n)*sum(x < breaks.x[i+1] & y < breaks.y[j+1] & 
                             x >= breaks.x[i] & y >= breaks.y[j])
       binplot.3d(c(breaks.x[i],breaks.x[i+1]),c(breaks.y[j],breaks.y[j+1]),
-                 scale*z[i,j],alpha=alpha)
+                 scale*z[i,j],alpha=alpha,topcol=col)
       }
     }
 }
 ################################################################################
 
 # Clearing the Scene:
-rgl.clear()
-rgl.clear(type="lights")
-rgl.clear(type="bbox")
+rgl.clear("all")
 
 rgl.bg(color="gray")
 rgl.light()
@@ -65,12 +71,12 @@ rgl.bg(col="#cccccc")
 # readline()
 
 # Clearing the Scene:
-rgl.clear()
+rgl.clear("shapes")
 
 # Defining transparency and colors:
 alpha<-0.7; topcol<-"#ff0000"; sidecol<-"#aaaaaa"
 
-# Setting up coordinstes for the quads and adding them to the scene:
+# Setting up coordinates for the quads and adding them to the scene:
 y<-x<-c(-1,1) ; z<-4; of<-0.3
 x12<-c(x[1],x[2],x[2],x[1]); x11<-rep(x[1],4); x22<-rep(x[2],4)
 z00<-rep(0,4); z0z<-c(0,0,z,z); zzz<-rep(z,4); y11<-rep(y[1],4)
@@ -99,7 +105,7 @@ rgl.lines(xl,zl,yl,col="#000000")
 # readline()
 
 # Clearing the Scene:
-rgl.clear()
+rgl.clear("shapes")
 
 # Choosing a lightgrey background:
 rgl.bg(col="#cccccc")
