@@ -2,6 +2,8 @@
 #include "types.h"
 
 #include <cstdlib>
+#include <stdlib.h> // for realoc and free
+#include <string.h> // for memcpy
 
 //
 // COLOR UTILS
